about summary refs log tree commit diff
path: root/src/test/compile-fail
diff options
context:
space:
mode:
authorBrian Anderson <banderson@mozilla.com>2012-08-06 12:34:08 -0700
committerBrian Anderson <banderson@mozilla.com>2012-08-06 15:36:30 -0700
commitecaf9e39c9435fa2de4fe393c4b263be36eb2d99 (patch)
tree775f69be65adff65551d96173dd797e32e2c3157 /src/test/compile-fail
parentd3a9bb1bd4a1d510bbaca2ab1121e4c85a239247 (diff)
downloadrust-ecaf9e39c9435fa2de4fe393c4b263be36eb2d99.tar.gz
rust-ecaf9e39c9435fa2de4fe393c4b263be36eb2d99.zip
Convert alt to match. Stop parsing alt
Diffstat (limited to 'src/test/compile-fail')
-rw-r--r--src/test/compile-fail/alt-arrows-block-then-binop.rs2
-rw-r--r--src/test/compile-fail/alt-join.rs2
-rw-r--r--src/test/compile-fail/alt-pattern-field-mismatch-2.rs2
-rw-r--r--src/test/compile-fail/alt-pattern-field-mismatch.rs2
-rw-r--r--src/test/compile-fail/alt-range-fail-dominate.rs10
-rw-r--r--src/test/compile-fail/alt-range-fail.rs6
-rw-r--r--src/test/compile-fail/alt-tag-nullary.rs2
-rw-r--r--src/test/compile-fail/alt-tag-unary.rs2
-rw-r--r--src/test/compile-fail/bad-alt.rs2
-rw-r--r--src/test/compile-fail/bad-record-pat-2.rs2
-rw-r--r--src/test/compile-fail/bad-record-pat.rs2
-rw-r--r--src/test/compile-fail/bogus-tag.rs2
-rw-r--r--src/test/compile-fail/borrowck-binding-mutbl.rs2
-rw-r--r--src/test/compile-fail/borrowck-issue-2657-1.rs2
-rw-r--r--src/test/compile-fail/borrowck-issue-2657-2.rs2
-rw-r--r--src/test/compile-fail/borrowck-no-cycle-in-exchange-heap.rs2
-rw-r--r--src/test/compile-fail/borrowck-pat-enum-in-box.rs8
-rw-r--r--src/test/compile-fail/borrowck-pat-enum.rs12
-rw-r--r--src/test/compile-fail/borrowck-pat-reassign-binding.rs2
-rw-r--r--src/test/compile-fail/borrowck-pat-reassign-sometimes-binding.rs2
-rw-r--r--src/test/compile-fail/borrowck-unchecked-with-borrow.rs4
-rw-r--r--src/test/compile-fail/deref-non-pointer.rs2
-rw-r--r--src/test/compile-fail/issue-1193.rs2
-rw-r--r--src/test/compile-fail/issue-2111.rs2
-rw-r--r--src/test/compile-fail/issue-2354.rs2
-rw-r--r--src/test/compile-fail/issue-2848.rs2
-rw-r--r--src/test/compile-fail/issue-2849.rs2
-rw-r--r--src/test/compile-fail/issue-3038.rs6
-rw-r--r--src/test/compile-fail/liveness-missing-ret2.rs4
-rw-r--r--src/test/compile-fail/liveness-unused.rs2
-rw-r--r--src/test/compile-fail/non-exhaustive-match-nested.rs2
-rw-r--r--src/test/compile-fail/non-exhaustive-match.rs14
-rw-r--r--src/test/compile-fail/occurs-check-3.rs2
-rw-r--r--src/test/compile-fail/or-patter-mismatch.rs2
-rw-r--r--src/test/compile-fail/pattern-tyvar-2.rs2
-rw-r--r--src/test/compile-fail/pattern-tyvar.rs2
-rw-r--r--src/test/compile-fail/regions-creating-enums.rs4
-rw-r--r--src/test/compile-fail/restricted-keyword1.rs2
-rw-r--r--src/test/compile-fail/unreachable-arm.rs2
39 files changed, 64 insertions, 64 deletions
diff --git a/src/test/compile-fail/alt-arrows-block-then-binop.rs b/src/test/compile-fail/alt-arrows-block-then-binop.rs
index 037e0c8b517..7b973633c7d 100644
--- a/src/test/compile-fail/alt-arrows-block-then-binop.rs
+++ b/src/test/compile-fail/alt-arrows-block-then-binop.rs
@@ -1,6 +1,6 @@
 fn main() {
 
-    alt 0 {
+    match 0 {
       0 => {
       } + 5 //~ ERROR unexpected token: `+`
     }
diff --git a/src/test/compile-fail/alt-join.rs b/src/test/compile-fail/alt-join.rs
index 1557ff12090..83dcc69609e 100644
--- a/src/test/compile-fail/alt-join.rs
+++ b/src/test/compile-fail/alt-join.rs
@@ -4,7 +4,7 @@
 fn my_fail() -> ! { fail; }
 
 fn main() {
-    alt true { false => { my_fail(); } true => { } }
+    match true { false => { my_fail(); } true => { } }
 
     log(debug, x); //~ ERROR unresolved name: x
     let x: int;
diff --git a/src/test/compile-fail/alt-pattern-field-mismatch-2.rs b/src/test/compile-fail/alt-pattern-field-mismatch-2.rs
index 6ba942decfc..617bb168629 100644
--- a/src/test/compile-fail/alt-pattern-field-mismatch-2.rs
+++ b/src/test/compile-fail/alt-pattern-field-mismatch-2.rs
@@ -6,7 +6,7 @@ fn main() {
     }
 
     fn foo(c: color) {
-        alt c {
+        match c {
           rgb(_, _, _) => { }
           cmyk(_, _, _, _) => { }
           no_color(_) => { }
diff --git a/src/test/compile-fail/alt-pattern-field-mismatch.rs b/src/test/compile-fail/alt-pattern-field-mismatch.rs
index 71f44764e14..9a54985efc1 100644
--- a/src/test/compile-fail/alt-pattern-field-mismatch.rs
+++ b/src/test/compile-fail/alt-pattern-field-mismatch.rs
@@ -6,7 +6,7 @@ fn main() {
     }
 
     fn foo(c: color) {
-        alt c {
+        match c {
           rgb(_, _) => { }
           //~^ ERROR this pattern has 2 fields, but the corresponding variant has 3 fields
           cmyk(_, _, _, _) => { }
diff --git a/src/test/compile-fail/alt-range-fail-dominate.rs b/src/test/compile-fail/alt-range-fail-dominate.rs
index d1ba0f625b1..f58d0865265 100644
--- a/src/test/compile-fail/alt-range-fail-dominate.rs
+++ b/src/test/compile-fail/alt-range-fail-dominate.rs
@@ -5,27 +5,27 @@
 //error-pattern: unreachable
 
 fn main() {
-    alt check 5u {
+    match check 5u {
       1u to 10u => { }
       5u to 6u => { }
     };
 
-    alt check 5u {
+    match check 5u {
       3u to 6u => { }
       4u to 6u => { }
     };
 
-    alt check 5u {
+    match check 5u {
       4u to 6u => { }
       4u to 6u => { }
     };
 
-    alt check 'c' {
+    match check 'c' {
       'A' to 'z' => {}
       'a' to 'z' => {}
     };
 
-    alt check 1.0 {
+    match check 1.0 {
       0.01 to 6.5 => {}
       0.02 => {}
     };
diff --git a/src/test/compile-fail/alt-range-fail.rs b/src/test/compile-fail/alt-range-fail.rs
index afda6d7015e..229b5c47eba 100644
--- a/src/test/compile-fail/alt-range-fail.rs
+++ b/src/test/compile-fail/alt-range-fail.rs
@@ -3,16 +3,16 @@
 //error-pattern: mismatched types
 
 fn main() {
-    alt 5u {
+    match 5u {
       6u to 1u => { }
       _ => { }
     };
 
-    alt "wow" {
+    match "wow" {
       "bar" to "foo" => { }
     };
 
-    alt 5u {
+    match 5u {
       'c' to 100u => { }
       _ => { }
     };
diff --git a/src/test/compile-fail/alt-tag-nullary.rs b/src/test/compile-fail/alt-tag-nullary.rs
index 4f34c675cef..9f7b471221d 100644
--- a/src/test/compile-fail/alt-tag-nullary.rs
+++ b/src/test/compile-fail/alt-tag-nullary.rs
@@ -3,5 +3,5 @@
 enum a { A, }
 enum b { B, }
 
-fn main() { let x: a = A; alt x { B => { } } }
+fn main() { let x: a = A; match x { B => { } } }
 
diff --git a/src/test/compile-fail/alt-tag-unary.rs b/src/test/compile-fail/alt-tag-unary.rs
index f0546574912..5902454c461 100644
--- a/src/test/compile-fail/alt-tag-unary.rs
+++ b/src/test/compile-fail/alt-tag-unary.rs
@@ -3,5 +3,5 @@
 enum a { A(int), }
 enum b { B(int), }
 
-fn main() { let x: a = A(0); alt x { B(y) => { } } }
+fn main() { let x: a = A(0); match x { B(y) => { } } }
 
diff --git a/src/test/compile-fail/bad-alt.rs b/src/test/compile-fail/bad-alt.rs
index 4d8de65492f..041f84bc6ee 100644
--- a/src/test/compile-fail/bad-alt.rs
+++ b/src/test/compile-fail/bad-alt.rs
@@ -2,5 +2,5 @@
 
 fn main() {
   let int x = 5;
-  alt x;
+  match x;
 }
diff --git a/src/test/compile-fail/bad-record-pat-2.rs b/src/test/compile-fail/bad-record-pat-2.rs
index 4c8d72444c1..c043a076042 100644
--- a/src/test/compile-fail/bad-record-pat-2.rs
+++ b/src/test/compile-fail/bad-record-pat-2.rs
@@ -1,3 +1,3 @@
 // error-pattern:did not expect a record with a field `q`
 
-fn main() { alt {x: 1, y: 2} { {x: x, q: q} => { } } }
+fn main() { match {x: 1, y: 2} { {x: x, q: q} => { } } }
diff --git a/src/test/compile-fail/bad-record-pat.rs b/src/test/compile-fail/bad-record-pat.rs
index 48155a0b529..d7e7fb16ad8 100644
--- a/src/test/compile-fail/bad-record-pat.rs
+++ b/src/test/compile-fail/bad-record-pat.rs
@@ -1,3 +1,3 @@
 // error-pattern:expected a record with 2 fields, found one with 1
 
-fn main() { alt {x: 1, y: 2} { {x: x} => { } } }
+fn main() { match {x: 1, y: 2} { {x: x} => { } } }
diff --git a/src/test/compile-fail/bogus-tag.rs b/src/test/compile-fail/bogus-tag.rs
index 0414bb5e867..06cfb60e1a8 100644
--- a/src/test/compile-fail/bogus-tag.rs
+++ b/src/test/compile-fail/bogus-tag.rs
@@ -6,7 +6,7 @@ enum color { rgb(int, int, int), rgba(int, int, int, int), }
 
 fn main() {
     let red: color = rgb(255, 0, 0);
-    alt red {
+    match red {
       rgb(r, g, b) => { debug!{"rgb"}; }
       hsl(h, s, l) => { debug!{"hsl"}; }
     }
diff --git a/src/test/compile-fail/borrowck-binding-mutbl.rs b/src/test/compile-fail/borrowck-binding-mutbl.rs
index 8a188fe9239..57c0375f4e4 100644
--- a/src/test/compile-fail/borrowck-binding-mutbl.rs
+++ b/src/test/compile-fail/borrowck-binding-mutbl.rs
@@ -4,7 +4,7 @@ fn impure(_v: ~[int]) {
 fn main() {
     let x = {mut f: ~[3]};
 
-    alt x {
+    match x {
       {f: v} => {
         impure(v); //~ ERROR illegal borrow unless pure: unique value in aliasable, mutable location
         //~^ NOTE impure due to access to impure function
diff --git a/src/test/compile-fail/borrowck-issue-2657-1.rs b/src/test/compile-fail/borrowck-issue-2657-1.rs
index 2d396bd591c..f8cbb52d996 100644
--- a/src/test/compile-fail/borrowck-issue-2657-1.rs
+++ b/src/test/compile-fail/borrowck-issue-2657-1.rs
@@ -1,6 +1,6 @@
 fn main() {
 let x = some(~1);
-alt x { //~ NOTE loan of immutable local variable granted here
+match x { //~ NOTE loan of immutable local variable granted here
   some(y) => {
     let _a <- x; //~ ERROR moving out of immutable local variable prohibited due to outstanding loan
   }
diff --git a/src/test/compile-fail/borrowck-issue-2657-2.rs b/src/test/compile-fail/borrowck-issue-2657-2.rs
index 85d062dd98c..ab6e63174aa 100644
--- a/src/test/compile-fail/borrowck-issue-2657-2.rs
+++ b/src/test/compile-fail/borrowck-issue-2657-2.rs
@@ -1,6 +1,6 @@
 fn main() {
 let x = some(~1);
-alt x {
+match x {
   some(y) => {
     let _b <- y; //~ ERROR moving out of pattern binding
   }
diff --git a/src/test/compile-fail/borrowck-no-cycle-in-exchange-heap.rs b/src/test/compile-fail/borrowck-no-cycle-in-exchange-heap.rs
index acb018dbb2d..ef696048219 100644
--- a/src/test/compile-fail/borrowck-no-cycle-in-exchange-heap.rs
+++ b/src/test/compile-fail/borrowck-no-cycle-in-exchange-heap.rs
@@ -5,7 +5,7 @@ enum cycle {
 fn main() {
     let x = ~node({mut a: ~empty});
     // Create a cycle!
-    alt check *x { //~ NOTE loan of immutable local variable granted here
+    match check *x { //~ NOTE loan of immutable local variable granted here
       node(y) => {
         y.a <- x; //~ ERROR moving out of immutable local variable prohibited due to outstanding loan
       }
diff --git a/src/test/compile-fail/borrowck-pat-enum-in-box.rs b/src/test/compile-fail/borrowck-pat-enum-in-box.rs
index 103de904609..cd4893f87f2 100644
--- a/src/test/compile-fail/borrowck-pat-enum-in-box.rs
+++ b/src/test/compile-fail/borrowck-pat-enum-in-box.rs
@@ -1,12 +1,12 @@
 fn match_imm_box(v: &const @option<int>) -> int {
-    alt *v {
+    match *v {
       @some(i) => {i}
       @none => {0}
     }
 }
 
 fn match_const_box(v: &const @const option<int>) -> int {
-    alt *v {
+    match *v {
       @some(i) => { i } // ok because this is pure
       @none => {0}
     }
@@ -15,7 +15,7 @@ fn match_const_box(v: &const @const option<int>) -> int {
 pure fn pure_process(_i: int) {}
 
 fn match_const_box_and_do_pure_things(v: &const @const option<int>) {
-    alt *v {
+    match *v {
       @some(i) => {
         pure_process(i)
       }
@@ -26,7 +26,7 @@ fn match_const_box_and_do_pure_things(v: &const @const option<int>) {
 fn process(_i: int) {}
 
 fn match_const_box_and_do_bad_things(v: &const @const option<int>) {
-    alt *v {
+    match *v {
       @some(i) => { //~ ERROR illegal borrow unless pure: enum variant in aliasable, mutable location
         process(i) //~ NOTE impure due to access to impure function
       }
diff --git a/src/test/compile-fail/borrowck-pat-enum.rs b/src/test/compile-fail/borrowck-pat-enum.rs
index 6dd37e647ac..b29321ed818 100644
--- a/src/test/compile-fail/borrowck-pat-enum.rs
+++ b/src/test/compile-fail/borrowck-pat-enum.rs
@@ -1,5 +1,5 @@
 fn match_ref(&&v: option<int>) -> int {
-    alt v {
+    match v {
       some(i) => {
         i
       }
@@ -8,14 +8,14 @@ fn match_ref(&&v: option<int>) -> int {
 }
 
 fn match_ref_unused(&&v: option<int>) {
-    alt v {
+    match v {
       some(_) => {}
       none => {}
     }
 }
 
 fn match_const_reg(v: &const option<int>) -> int {
-    alt *v {
+    match *v {
       some(i) => {i} // OK because this is pure
       none => {0}
     }
@@ -25,14 +25,14 @@ fn impure(_i: int) {
 }
 
 fn match_const_reg_unused(v: &const option<int>) {
-    alt *v {
+    match *v {
       some(_) => {impure(0)} // OK because nothing is captured
       none => {}
     }
 }
 
 fn match_const_reg_impure(v: &const option<int>) {
-    alt *v {
+    match *v {
       some(i) => {impure(i)} //~ ERROR illegal borrow unless pure: enum variant in aliasable, mutable location
       //~^ NOTE impure due to access to impure function
       none => {}
@@ -40,7 +40,7 @@ fn match_const_reg_impure(v: &const option<int>) {
 }
 
 fn match_imm_reg(v: &option<int>) {
-    alt *v {
+    match *v {
       some(i) => {impure(i)} // OK because immutable
       none => {}
     }
diff --git a/src/test/compile-fail/borrowck-pat-reassign-binding.rs b/src/test/compile-fail/borrowck-pat-reassign-binding.rs
index 2d7f33e6620..02604f65227 100644
--- a/src/test/compile-fail/borrowck-pat-reassign-binding.rs
+++ b/src/test/compile-fail/borrowck-pat-reassign-binding.rs
@@ -2,7 +2,7 @@
 
 fn main() {
     let mut x: option<int> = none;
-    alt x { //~ NOTE loan of mutable local variable granted here
+    match x { //~ NOTE loan of mutable local variable granted here
       none => {}
       some(i) => {
         // Not ok: i is an outstanding ptr into x.
diff --git a/src/test/compile-fail/borrowck-pat-reassign-sometimes-binding.rs b/src/test/compile-fail/borrowck-pat-reassign-sometimes-binding.rs
index 12c2d0ef6e8..42dd5024603 100644
--- a/src/test/compile-fail/borrowck-pat-reassign-sometimes-binding.rs
+++ b/src/test/compile-fail/borrowck-pat-reassign-sometimes-binding.rs
@@ -2,7 +2,7 @@
 
 fn main() {
     let mut x = none;
-    alt x { //~ NOTE loan of mutable local variable granted here
+    match x { //~ NOTE loan of mutable local variable granted here
       none => {
         // It is ok to reassign x here, because there is in
         // fact no outstanding loan of x!
diff --git a/src/test/compile-fail/borrowck-unchecked-with-borrow.rs b/src/test/compile-fail/borrowck-unchecked-with-borrow.rs
index 34031aa70d6..86a855de6f1 100644
--- a/src/test/compile-fail/borrowck-unchecked-with-borrow.rs
+++ b/src/test/compile-fail/borrowck-unchecked-with-borrow.rs
@@ -2,7 +2,7 @@ fn impure(_i: int) {}
 
 // check that unchecked alone does not override borrowck:
 fn foo(v: &const option<int>) {
-    alt *v {
+    match *v {
       some(i) => {
         //~^ ERROR illegal borrow unless pure: enum variant in aliasable, mutable location
         unchecked {
@@ -15,7 +15,7 @@ fn foo(v: &const option<int>) {
 }
 
 fn bar(v: &const option<int>) {
-    alt *v {
+    match *v {
       some(i) => {
         unsafe {
             impure(i);
diff --git a/src/test/compile-fail/deref-non-pointer.rs b/src/test/compile-fail/deref-non-pointer.rs
index 5468a46a6a7..8c23b1db2de 100644
--- a/src/test/compile-fail/deref-non-pointer.rs
+++ b/src/test/compile-fail/deref-non-pointer.rs
@@ -1,6 +1,6 @@
 // error-pattern:cannot be dereferenced
 fn main() {
-  alt *1 {
+  match *1 {
       _ => { fail; }
   }
 }
\ No newline at end of file
diff --git a/src/test/compile-fail/issue-1193.rs b/src/test/compile-fail/issue-1193.rs
index 4ac885e5b10..e9a5d91c9d2 100644
--- a/src/test/compile-fail/issue-1193.rs
+++ b/src/test/compile-fail/issue-1193.rs
@@ -6,7 +6,7 @@ mod foo {
     const b : t = 1u8;
 
     fn bar(v: t) -> bool {
-        alt v {
+        match v {
             a => { return true; }
             b => { return false; }
         }
diff --git a/src/test/compile-fail/issue-2111.rs b/src/test/compile-fail/issue-2111.rs
index f5639a887f0..7c7ec4f5f8f 100644
--- a/src/test/compile-fail/issue-2111.rs
+++ b/src/test/compile-fail/issue-2111.rs
@@ -1,5 +1,5 @@
 fn foo(a: option<uint>, b: option<uint>) {
-  alt (a,b) { //~ ERROR: non-exhaustive patterns: none not covered
+  match (a,b) { //~ ERROR: non-exhaustive patterns: none not covered
     (some(a), some(b)) if a == b => { }
     (some(_), none) |
     (none, some(_)) => { }
diff --git a/src/test/compile-fail/issue-2354.rs b/src/test/compile-fail/issue-2354.rs
index cf7a36224bb..ebda510e879 100644
--- a/src/test/compile-fail/issue-2354.rs
+++ b/src/test/compile-fail/issue-2354.rs
@@ -5,7 +5,7 @@
   xfailed for now (see Issue #2354)
  */
 fn foo() { //~ ERROR this open brace is not closed
-  alt some(x) {
+  match some(x) {
       some(y) { fail; }
       none    { fail; }
 }
diff --git a/src/test/compile-fail/issue-2848.rs b/src/test/compile-fail/issue-2848.rs
index 376426bb82e..c721887e496 100644
--- a/src/test/compile-fail/issue-2848.rs
+++ b/src/test/compile-fail/issue-2848.rs
@@ -8,7 +8,7 @@ mod bar {
 
 fn main() {
     import bar::{alpha, charlie};
-    alt alpha {
+    match alpha {
       alpha | beta => {} //~ ERROR: inconsistent number of bindings
       charlie => {}
     }
diff --git a/src/test/compile-fail/issue-2849.rs b/src/test/compile-fail/issue-2849.rs
index 6085fc9fe8f..5e8a9905c2f 100644
--- a/src/test/compile-fail/issue-2849.rs
+++ b/src/test/compile-fail/issue-2849.rs
@@ -1,7 +1,7 @@
 enum foo { alpha, beta(int) }
 
 fn main() {
-    alt alpha {
+    match alpha {
       alpha | beta(i) => {} //~ ERROR inconsistent number of bindings
     }
 }
diff --git a/src/test/compile-fail/issue-3038.rs b/src/test/compile-fail/issue-3038.rs
index f5aa30c1416..ec66d3bafe6 100644
--- a/src/test/compile-fail/issue-3038.rs
+++ b/src/test/compile-fail/issue-3038.rs
@@ -8,17 +8,17 @@ enum k { m(int, int) }
 fn main()
 {
 
-    let _z = alt g(1, 2) {
+    let _z = match g(1, 2) {
       g(x, x) => { log(debug, x + x); }
       //~^ ERROR Identifier x is bound more than once in the same pattern
     };
 
-    let _z = alt i(l(1, 2), m(3, 4)) {
+    let _z = match i(l(1, 2), m(3, 4)) {
       i(l(x, _), m(_, x))  //~ ERROR Identifier x is bound more than once in the same pattern
         => { log(error, x + x); }
     };
 
-    let _z = alt (1, 2) {
+    let _z = match (1, 2) {
         (x, x) => { x } //~ ERROR Identifier x is bound more than once in the same pattern
     };
 
diff --git a/src/test/compile-fail/liveness-unused.rs b/src/test/compile-fail/liveness-unused.rs
index 4f9e62e0502..c1d4cdb4a57 100644
--- a/src/test/compile-fail/liveness-unused.rs
+++ b/src/test/compile-fail/liveness-unused.rs
@@ -27,7 +27,7 @@ fn f3b() {
 }
 
 fn f4() {
-    alt some(3) {
+    match some(3) {
       some(i) => {
       }
       none => {}
diff --git a/src/test/compile-fail/non-exhaustive-match-nested.rs b/src/test/compile-fail/non-exhaustive-match-nested.rs
index dea250a734c..01641f5b9c7 100644
--- a/src/test/compile-fail/non-exhaustive-match-nested.rs
+++ b/src/test/compile-fail/non-exhaustive-match-nested.rs
@@ -5,7 +5,7 @@ enum u { c, d }
 
 fn main() {
   let x = a(c);
-  alt x {
+  match x {
       a(d) => { fail ~"hello"; }
       b => { fail ~"goodbye"; }
     }
diff --git a/src/test/compile-fail/non-exhaustive-match.rs b/src/test/compile-fail/non-exhaustive-match.rs
index e712406ba19..173fd2b4109 100644
--- a/src/test/compile-fail/non-exhaustive-match.rs
+++ b/src/test/compile-fail/non-exhaustive-match.rs
@@ -2,25 +2,25 @@ enum t { a, b, }
 
 fn main() {
     let x = a;
-    alt x { b => { } } //~ ERROR non-exhaustive patterns
-    alt true { //~ ERROR non-exhaustive patterns
+    match x { b => { } } //~ ERROR non-exhaustive patterns
+    match true { //~ ERROR non-exhaustive patterns
       true => {}
     }
-    alt @some(10) { //~ ERROR non-exhaustive patterns
+    match @some(10) { //~ ERROR non-exhaustive patterns
       @none => {}
     }
-    alt (2, 3, 4) { //~ ERROR non-exhaustive patterns
+    match (2, 3, 4) { //~ ERROR non-exhaustive patterns
       (_, _, 4) => {}
     }
-    alt (a, a) { //~ ERROR non-exhaustive patterns
+    match (a, a) { //~ ERROR non-exhaustive patterns
       (a, b) => {}
       (b, a) => {}
     }
-    alt a { //~ ERROR b not covered
+    match a { //~ ERROR b not covered
       a => {}
     }
     // This is exhaustive, though the algorithm got it wrong at one point
-    alt (a, b) {
+    match (a, b) {
       (a, _) => {}
       (_, a) => {}
       (b, b) => {}
diff --git a/src/test/compile-fail/occurs-check-3.rs b/src/test/compile-fail/occurs-check-3.rs
index 207bbd91cc5..e8c8f32b72f 100644
--- a/src/test/compile-fail/occurs-check-3.rs
+++ b/src/test/compile-fail/occurs-check-3.rs
@@ -1,4 +1,4 @@
 // error-pattern:mismatched types
 // From Issue #778
 enum clam<T> { a(T), }
-fn main() { let c; c = a(c); alt c { a::<int>(_) => { } } }
+fn main() { let c; c = a(c); match c { a::<int>(_) => { } } }
diff --git a/src/test/compile-fail/or-patter-mismatch.rs b/src/test/compile-fail/or-patter-mismatch.rs
index 37d194cbd50..f309ead4623 100644
--- a/src/test/compile-fail/or-patter-mismatch.rs
+++ b/src/test/compile-fail/or-patter-mismatch.rs
@@ -2,4 +2,4 @@
 
 enum blah { a(int, int, uint), b(int, int), }
 
-fn main() { alt a(1, 1, 2u) { a(_, x, y) | b(x, y) => { } } }
+fn main() { match a(1, 1, 2u) { a(_, x, y) | b(x, y) => { } } }
diff --git a/src/test/compile-fail/pattern-tyvar-2.rs b/src/test/compile-fail/pattern-tyvar-2.rs
index 1dee20e0ef6..f1e8224efc5 100644
--- a/src/test/compile-fail/pattern-tyvar-2.rs
+++ b/src/test/compile-fail/pattern-tyvar-2.rs
@@ -8,6 +8,6 @@ import option::some;
 
 enum bar { t1((), option<~[int]>), t2, }
 
-fn foo(t: bar) -> int { alt t { t1(_, some(x)) => { return x * 3; } _ => { fail; } } }
+fn foo(t: bar) -> int { match t { t1(_, some(x)) => { return x * 3; } _ => { fail; } } }
 
 fn main() { }
diff --git a/src/test/compile-fail/pattern-tyvar.rs b/src/test/compile-fail/pattern-tyvar.rs
index 2622dadc040..8b7c065dbf7 100644
--- a/src/test/compile-fail/pattern-tyvar.rs
+++ b/src/test/compile-fail/pattern-tyvar.rs
@@ -8,7 +8,7 @@ import option::some;
 enum bar { t1((), option<~[int]>), t2, }
 
 fn foo(t: bar) {
-    alt t {
+    match t {
       t1(_, some::<int>(x)) => {
         log(debug, x);
       }
diff --git a/src/test/compile-fail/regions-creating-enums.rs b/src/test/compile-fail/regions-creating-enums.rs
index 0702618c68c..6cacf49300d 100644
--- a/src/test/compile-fail/regions-creating-enums.rs
+++ b/src/test/compile-fail/regions-creating-enums.rs
@@ -11,14 +11,14 @@ fn build() {
 }
 
 fn compute(x: &ast) -> uint {
-    alt *x {
+    match *x {
       num(x) => { x }
       add(x, y) => { compute(x) + compute(y) }
     }
 }
 
 fn map_nums(x: &ast, f: fn(uint) -> uint) -> &ast {
-    alt *x {
+    match *x {
       num(x) => {
         return &num(f(x)); //~ ERROR illegal borrow
       }
diff --git a/src/test/compile-fail/restricted-keyword1.rs b/src/test/compile-fail/restricted-keyword1.rs
index 2a9f5838c85..c301d8199de 100644
--- a/src/test/compile-fail/restricted-keyword1.rs
+++ b/src/test/compile-fail/restricted-keyword1.rs
@@ -1,7 +1,7 @@
 // error-pattern:found `let` in restricted position
 
 fn main() {
-    alt true {
+    match true {
       {let} { }
     }
 }
diff --git a/src/test/compile-fail/unreachable-arm.rs b/src/test/compile-fail/unreachable-arm.rs
index 1865fe6aff9..71875e92a8f 100644
--- a/src/test/compile-fail/unreachable-arm.rs
+++ b/src/test/compile-fail/unreachable-arm.rs
@@ -2,4 +2,4 @@
 
 enum foo { a(@foo, int), b(uint), }
 
-fn main() { alt b(1u) { b(_) | a(@_, 1) => { } a(_, 1) => { } } }
+fn main() { match b(1u) { b(_) | a(@_, 1) => { } a(_, 1) => { } } }
diff --git a/src/test/compile-fail/liveness-missing-ret2.rs b/src/test/compile-fail/liveness-missing-ret2.rs
index e1803b0248a..5f488c4dc5a 100644
--- a/src/test/compile-fail/liveness-missing-ret2.rs
+++ b/src/test/compile-fail/liveness-missing-ret2.rs
@@ -1,9 +1,9 @@
 // error-pattern: not all control paths return a value
 
 fn f() -> int {
     // Make sure typestate doesn't interpreturn this alt expression
     // as the function result
-    alt check true { true => { } };
+    match check true { true => { } };
 }
 
 fn main() { }
@@ -1,9 +1,9 @@
 
 fn f() -> int {
-    // Make sure typestate doesn't interpreturn this alt expression
+    // Make sure typestate doesn't interpreturn this match expression
     // as the function result